==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/user/messages/cs/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => 'Nastavení <strong>Účtu</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Potvrzení</strong> nové emailové adresy',
    '<strong>Permissions</strong>' => '<strong>Oprávnění</strong>',
    '<strong>Your</strong> Account' => '<strong>Váš</strong> účet',
    '<strong>Your</strong> profile' => '<strong>Váš</strong> profil',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Přidejte do svého profilu značky, které vás popisují a zdůrazňují vaše dovednosti a zájmy. Vaše značky se zobrazí ve vašem profilu a v adresáři "Lidé".',
    'All your personal data will be irrevocably deleted.' => 'Všechny vaše osobní údaje budou nenávratně vymazány.',
    'Are you sure that you want to delete your account?' => 'Jste si jisti, že chcete svůj účet odstranit?',
    'Blocked users' => 'Blokovaní uživatelé',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Změna uživatelského jména může způsobit, že některé odkazy nebudou použitelné, například staré odkazy na profil.',
    'Confirm' => 'Potvrdit',
    'Current password' => 'Současné heslo',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Definujte základní nastavení svého profilu. Můžete přidat štítky, které vám vyhovují, zvolit jazyk a časové pásmo a blokovat nezdvořilé uživatele.',
    'Delete account' => 'Smazat účet',
    'Do you really want to delete your icon image?' => 'Opravdu chcete smazat svůj obrázek?',
    'Do you really want to delete your logo image?' => 'Opravdu chcete smazat logo?',
    'E-Mail' => 'E-mail',
    'E-Mail change' => 'Změna e-mailové adresy',
    'Enter your password to continue' => 'Nejdříve zadejte heslo',
    'General' => 'Obecné',
    'Hello' => 'Dobrý den',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Zde můžete upravit obecná data profilu, která je viditelná na stránce o vašem profilu.',
    'Hide introduction tour panel on dashboard' => 'Skrýt úvodní panel prohlídky na nastěnce',
    'Hide my online status' => 'Skrýt můj online stav',
    'Invalid link! Please make sure that you entered the entire url.' => 'Neplatný odkaz! Prosím, ujistěte se, že jste zadal(a) celou URL adresu.',
    'Language' => 'Jazyk',
    'Markdown Editor Mode' => 'Režim editoru Markdown',
    'Modules' => 'Moduly',
    'New E-Mail address' => 'Nová e-mailová adresa',
    'New User name' => 'Nové uživatelské jméno',
    'Not registered users' => 'Neregistrovaní uživatelé',
    'Notifications' => 'Upozornění',
    'Other users' => 'Ostatní uživatelé',
    'Password Recovery' => 'Obnovení hesla',
    'Permissions' => 'Práva',
    'Profile' => 'Profil',
    'Profile Tags' => 'Značky profilu',
    'Profile visibility' => 'Viditelnost profilu',
    'Registered users only' => 'Pouze registrovaným uživatelům',
    'Save' => 'Uložit',
    'Save profile' => 'Uložit profil',
    'The entered e-mail address is already in use by another user.' => 'Zadaná e-mailová adresa je již používána jiným uživatelem.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Tato nastavení vám umožňují určit, jaká oprávnění chcete udělit návštěvníkům vašeho vlastního profilu. Každý uživatel si může libovolně upravit nastavení pro svůj vlastní profil.',
    'TimeZone' => 'Časové pásmo',
    'Username has been changed' => 'Uživatelské jméno bylo změněno',
    'Users' => 'Uživatelé',
    'Visible for all (also unregistered users)' => 'Viditelné všem (i neregistrovaným)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Právě jsme vám poslali potvrzovací e-mail na vaši novou adresu.<br />Postupujte prosím podle intrukcí uvnitř e-mailu.',
    'You are currently the owner of following spaces:' => 'V současné době jste vlastníkem následujících prostor:',
    'You cannot use this username.' => 'Toto uživatelské jméno nemůžete použít.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Požádal(a) jste o změnu vaší e-mailové adresy.<br>Vaše nová e-mailová adresa je: {newemail}<br><br>Pro potvrzení této změny prosím klikněte na tlačítko níže.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Úspěšně jste změnili své uživatelské jméno.<br>Vaše nové uživatelské jméno je {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Před odstraněním účtu je nutné převést vlastnictví nebo odstranit tato místa.',
    'Your account cannot be deleted!' => 'Váš účet nelze smazat!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Vaše aktuální e-mailová adresa je <b> {email} </ b>. Zde můžete změnit svou aktuální e-mailovou adresu.',
    'Your current password can be changed here.' => 'Zde můžete změnit své současné heslo.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Vaše aktuální uživatelské jméno je <b>{username}</b>. Zde můžete změnit své aktuální uživatelské jméno.',
    'Your e-mail address has been successfully changed to {email}.' => 'Vaše e-mailová adresa byla úspěšně změněna na: {email}',
    'Your friends' => 'Vaši přátelé',
    'Your password has been successfully changed!' => 'Vaše heslo bylo úspěšně změněno!',
    'Your username has been changed' => 'Vaše uživatelské jméno bylo změněno',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Vaše uživatelské jméno bylo úspěšně změněno. <br> Právě jsme vám zaslali e-mail s novými informacemi.',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
    'Plain' => '',
    'Rich Text' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/cs/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => 'Nastavení <strong>Účtu</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Potvrzení</strong> nové emailové adresy',
    '<strong>Permissions</strong>' => '<strong>Oprávnění</strong>',
    '<strong>Your</strong> Account' => '<strong>Váš</strong> účet',
    '<strong>Your</strong> profile' => '<strong>Váš</strong> profil',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Přidejte do svého profilu značky, které vás popisují a zdůrazňují vaše dovednosti a zájmy. Vaše značky se zobrazí ve vašem profilu a v adresáři "Lidé".',
    'All your personal data will be irrevocably deleted.' => 'Všechny vaše osobní údaje budou nenávratně vymazány.',
    'Are you sure that you want to delete your account?' => 'Jste si jisti, že chcete svůj účet odstranit?',
    'Blocked users' => 'Blokovaní uživatelé',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Změna uživatelského jména může způsobit, že některé odkazy nebudou použitelné, například staré odkazy na profil.',
    'Confirm' => 'Potvrdit',
    'Current password' => 'Současné heslo',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Definujte základní nastavení svého profilu. Můžete přidat štítky, které vám vyhovují, zvolit jazyk a časové pásmo a blokovat nezdvořilé uživatele.',
    'Delete account' => 'Smazat účet',
    'Do you really want to delete your icon image?' => 'Opravdu chcete smazat svůj obrázek?',
    'Do you really want to delete your logo image?' => 'Opravdu chcete smazat logo?',
    'E-Mail' => 'E-mail',
    'E-Mail change' => 'Změna e-mailové adresy',
    'Enter your password to continue' => 'Nejdříve zadejte heslo',
    'General' => 'Obecné',
    'Hello' => 'Dobrý den',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Zde můžete upravit obecná data profilu, která je viditelná na stránce o vašem profilu.',
    'Hide introduction tour panel on dashboard' => 'Skrýt úvodní panel prohlídky na nastěnce',
    'Hide my online status' => 'Skrýt můj online stav',
    'Invalid link! Please make sure that you entered the entire url.' => 'Neplatný odkaz! Prosím, ujistěte se, že jste zadal(a) celou URL adresu.',
    'Language' => 'Jazyk',
    'Markdown Editor Mode' => 'Režim editoru Markdown',
    'Modules' => 'Moduly',
    'New E-Mail address' => 'Nová e-mailová adresa',
    'New User name' => 'Nové uživatelské jméno',
    'Not registered users' => 'Neregistrovaní uživatelé',
    'Notifications' => 'Upozornění',
    'Other users' => 'Ostatní uživatelé',
    'Password Recovery' => 'Obnovení hesla',
    'Permissions' => 'Práva',
    'Profile' => 'Profil',
    'Profile Tags' => 'Značky profilu',
    'Profile visibility' => 'Viditelnost profilu',
    'Registered users only' => 'Pouze registrovaným uživatelům',
    'Save' => 'Uložit',
    'Save profile' => 'Uložit profil',
    'The entered e-mail address is already in use by another user.' => 'Zadaná e-mailová adresa je již používána jiným uživatelem.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Tato nastavení vám umožňují určit, jaká oprávnění chcete udělit návštěvníkům vašeho vlastního profilu. Každý uživatel si může libovolně upravit nastavení pro svůj vlastní profil.',
    'TimeZone' => 'Časové pásmo',
    'Username has been changed' => 'Uživatelské jméno bylo změněno',
    'Users' => 'Uživatelé',
    'Visible for all (also unregistered users)' => 'Viditelné všem (i neregistrovaným)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Právě jsme vám poslali potvrzovací e-mail na vaši novou adresu.<br />Postupujte prosím podle intrukcí uvnitř e-mailu.',
    'You are currently the owner of following spaces:' => 'V současné době jste vlastníkem následujících prostor:',
    'You cannot use this username.' => 'Toto uživatelské jméno nemůžete použít.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Požádal(a) jste o změnu vaší e-mailové adresy.<br>Vaše nová e-mailová adresa je: {newemail}<br><br>Pro potvrzení této změny prosím klikněte na tlačítko níže.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Úspěšně jste změnili své uživatelské jméno.<br>Vaše nové uživatelské jméno je {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Před odstraněním účtu je nutné převést vlastnictví nebo odstranit tato místa.',
    'Your account cannot be deleted!' => 'Váš účet nelze smazat!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Vaše aktuální e-mailová adresa je <b> {email} </ b>. Zde můžete změnit svou aktuální e-mailovou adresu.',
    'Your current password can be changed here.' => 'Zde můžete změnit své současné heslo.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Vaše aktuální uživatelské jméno je <b>{username}</b>. Zde můžete změnit své aktuální uživatelské jméno.',
    'Your e-mail address has been successfully changed to {email}.' => 'Vaše e-mailová adresa byla úspěšně změněna na: {email}',
    'Your friends' => 'Vaši přátelé',
    'Your password has been successfully changed!' => 'Vaše heslo bylo úspěšně změněno!',
    'Your username has been changed' => 'Vaše uživatelské jméno bylo změněno',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Vaše uživatelské jméno bylo úspěšně změněno. <br> Právě jsme vám zaslali e-mail s novými informacemi.',
    'Do you really want to delete your login background image?' => '',
    'Do you really want to delete your mail header image?' => '',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
    'Plain' => '',
    'Rich Text' => '',
];
